@@ -46,7 +46,7 @@ pub async fn subscribe_oids<R: Rpc>(rpc: &R, masks: &OIDMaskList, kind: EventKin
     let topics: Vec<String> = masks
         .oid_masks()
         .iter()
-        .map(|mask| format!("{}{}", kind.topic(), mask.to_path()))
+        .map(|mask| format!("{}{}", kind.topic(), mask.as_path()))
         .collect();
     rpc.client()
         .lock()
@@ -417,9 +417,9 @@ where
                 )));
             }
         }
-    } else if !initial.can_rof() {
+    } else if !initial.can_rtf() {
         return Err(Error::failed(
-            "the service is started in react-on-fail mode, but rof disabled for the service",
+            "the service is started in react-to-fail mode, but rtf disabled for the service",
         ));
     }
     initial
