@@ -1,4 +1,6 @@
-use eva_common::events::{LocalStateEvent, RawStateEventOwned, RemoteStateEvent};
+use eva_common::events::{
+    LocalStateEvent, RawStateEventOwned, RemoteStateEvent, ReplicationStateEvent,
+};
 use eva_common::prelude::*;
 use serde::{Deserialize, Deserializer, Serialize, Serializer};
 use std::fmt;
@@ -319,6 +321,16 @@ impl FullItemState {
             t: state.t,
         }
     }
+    pub fn into_replication_state_event(self, node_name: &str) -> ReplicationStateEvent {
+        ReplicationStateEvent {
+            status: self.status,
+            value: self.value,
+            act: self.act,
+            ieid: self.ieid,
+            t: self.t,
+            node: node_name.to_owned(),
+        }
+    }
 }
 
 impl From<FullItemState> for LocalStateEvent {
